Overview
========

.. automodule:: erika
    :members:
    :undoc-members:

Entry point
-----------

.. automodule:: erika.main
    :members:
    :undoc-members:
    
Version
-------

.. automodule:: erika.__version__
    :members:
    :undoc-members:
    :special-members:

Configuration
-------------

.. automodule:: erika.config
    :members:
    :undoc-members:
